package com.atlassian.confluence.test.rpc;

import com.atlassian.confluence.rpc.NotPermittedException;
import com.atlassian.confluence.rpc.RemoteException;

import java.util.Vector;

public interface FuncTestRpcHandler
{
    /**
     * Log a message to the server's console.
     * <p/>
     * Only administrators can log messages.
     * <p/>
     * The destination of the message has the following valid values:
     * <ul>
     * <li>info - message will be logged at INFO level
     * <li>debug - message will be logged at DEBUG level
     * <li>warn - message will be logged at WARN level
     * <li>error - message will be logged at ERROR level
     * <li>sout - message will be written via System.out.println
     * <li>serr - message will be written via System.err.println
     * </ul>
     *
     * @param token         The token idenfitying the user.
     * @param destination   The destination of the message to be logged
     * @param message       The text message to be logged to the console
     * @return boolean      True if the message is logged (ie destination is a valid level)
     */
    boolean logMessage(String token, String destination, String message) throws NotPermittedException, RemoteException;

    /**
     * Kill all the users, groups and spaces except the provided lists.
     */
    boolean nukeForTests(String token, Vector usersToKeep, Vector groupsToKeep, Vector spaceKeysToKeep) throws NotPermittedException, RemoteException;

    /**
     * Create a whole series of attachments on a single page.
     */
    boolean massCreateAttachments(String token, String pageId, String prefix, String numAttachments) throws Exception;

    /**
     * Reset the global theme to the default theme.
     */
    boolean resetTheme(String token) throws Exception;

    /**
     * Returns a vector of class names from the last 10 events fired.
     */
    Vector getRecentEvents(String token) throws Exception;

    /**
     * Tests a Spring bean -- used to test Spring plugin upload/remove
     */
    boolean checkSpringBean(String token, String name);

    /**
     * Tests a Spring bean -- used to test Spring plugin upload/remove
     */
    boolean checkNoSpringBean(String token, String name);

    /**
     * Shutdown the quartz scheduler to ensure single threadedness for testing
     */
    boolean shutdownQuartz(String token) throws Exception;

    /**
     * Remove a key from Bandana
     */
    boolean removeBandanaKey(String token, String space, String key);

    /**
     * Get the content property keys for a content entity given its id
     */
    Vector getContentPropertyKeys(String token, String entityId);

    /***
     * Sets a text content property for a content entity given its id
     */
    boolean setContentTextProperty(String token, String entityId, String key, String value);

    /**
     * Gets the personal information id for a given username 
     */
    String getPersonalInformationId(String token, String username);

    /**
     * Map a key to a value for a given cache.  Only accepts strings.  This allows us to manipulate
     * the number of entries in the cache.  This method will create the named cache if it doesn't exist.
     *
     * @return true because void is not allowed.
     */
    boolean putStringMappingInCache(String token, String cacheName, String key, String value) throws Exception;

    /**
     * Flushes all the caches.
     *
     * @return true because void isn't allowed.
     */
    boolean flushAllCaches(String token) throws Exception;
}
