package com.atlassian.confluence.extra.userlister;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.HashMap;

import com.atlassian.confluence.ConfluenceTestCase;
import com.atlassian.confluence.security.SpacePermissionManager;
import com.atlassian.confluence.security.SpacePermission;
import com.atlassian.confluence.core.AbstractConfluenceSpringPersistenceTest;
import com.atlassian.confluence.extra.userlister.model.UserList;
import com.atlassian.confluence.extra.userlister.model.ListedUser;
import com.atlassian.confluence.user.UserAccessor;
import com.atlassian.confluence.user.DefaultUserAccessor;
import com.atlassian.user.User;
import com.atlassian.user.repository.DefaultRepository;
import com.atlassian.user.impl.memory.MemoryUserManager;
import com.atlassian.user.impl.memory.provider.MemoryProvider;
import com.atlassian.user.impl.osuser.security.password.OSUPasswordEncryptor;
import com.atlassian.user.UserManager;
import com.atlassian.user.search.page.Pager;

public class TestUserList extends AbstractConfluenceSpringPersistenceTest
{
    private UserAccessor userAccessor;
    private UserList userList;
    private Map eligibleUsers;
    private SpacePermissionManager spacePermissionManager;

    public void setUp() throws Exception
    {
        super.setUp();

        userAccessor = (UserAccessor) context.getBean("userAccessor");
        spacePermissionManager = (SpacePermissionManager) context.getBean("spacePermissionManagerTarget");

        userList = new UserList(null, userAccessor);

        addUserWithUsePermission("user1");
        addUserWithUsePermission("user2");
        addUserWithUsePermission("user3");

        eligibleUsers = new HashMap();
        eligibleUsers.put("session1", "user1");
    }

    protected void tearDown() throws Exception
    {
        userAccessor = null;
        userList = null;
        eligibleUsers = null;
        spacePermissionManager = null;

        super.tearDown();
    }

    public void testBuildAllUsers() throws Exception
    {
        userList.build(false, eligibleUsers.values(), false);

        List users = userList.getUsers();
        Object[] userNames = users.toArray();
        assertEquals(3, users.size());
        assertUserState(userNames, 0, "user1", true);
        assertUserState(userNames, 1, "user2", false);
        assertUserState(userNames, 2, "user3", false);
    }

    public void testBuildLoggedInUsers() throws Exception
    {
        userList.build(true, eligibleUsers.values(), true);

        List users = userList.getUsers();
        Object[] userNames = users.toArray();
        assertEquals(1, users.size());
        assertUserState(userNames, 0, "user1", true);
    }

    public void testBuildLoggedOutUsers() throws Exception
    {
        userList.build(true, eligibleUsers.values(), false);

        List users = userList.getUsers();
        Object[] userNames = users.toArray();
        assertEquals(2, users.size());
        assertUserState(userNames, 0, "user2", false);
        assertUserState(userNames, 1, "user3", false);
    }

    private User addUserWithUsePermission(String userName) throws Exception
    {
        spacePermissionManager.savePermission(new SpacePermission(SpacePermission.USE_CONFLUENCE_PERMISSION, null, null, userName));
        return userAccessor.createUser(userName);
    }

    private void assertUserState(Object[] userNames, int index, String name, boolean loggedIn)
    {
        ListedUser listedUser = ((ListedUser) userNames[index]);
        assertEquals(name, listedUser.getName());
        assertEquals(loggedIn, listedUser.isLoggedIn());
    }
}
